@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use vars qw/$VERSION/;
 
-$Test::Stream::VERSION = '1.302008';
+$Test::Stream::VERSION = '1.302009';
 $VERSION = eval $VERSION;
 
 use Scalar::Util qw/reftype/;
@@ -14,9 +14,14 @@ use Test::Stream::IPC;
 use Test::Stream::Sync;
 
 use Test::Stream::Context qw/context/;
-use Test::Stream::DeepCheck qw/strict_compare=is_deeply relaxed_compare=mostly_like check/;
 use Test::Stream::Util qw/try/;
 
+use Test::Stream::DeepCheck(
+    qw/check/,
+    strict_compare  => { -as => 'is_deeply'   },
+    relaxed_compare => { -as => 'mostly_like' },
+);
+
 use Test::Stream::Exporter qw/default_exports exports export_to/;
 exports qw/context/;
 default_exports qw{
@@ -241,7 +246,7 @@ sub skip {
 }
 
 BEGIN {
-    for my $op (qw/isa can does/) {
+    for my $op (qw/isa can DOES/) {
         my $sub = sub($;@) {
             my ($thing, @items) = @_;
             my $ctx = context();
@@ -274,7 +279,7 @@ BEGIN {
             return !@bad;
         };
         no strict 'refs';
-        *{"${op}_ok"} = $sub;
+        *{lc($op) . "_ok"} = $sub;
     }
 }
 
@@ -407,8 +412,41 @@ L<Test::Stream::IPC> to manually cull results where you want them:
     cull()
     ...
 
+=head1 OTHER COMMON TOOLS
+
+Unlike L<Test::More> which bundled most if not all of its functionality into a
+single import, L<Test::Stream> breaks out the non-trivial tools into other
+modules that you can load as needed. The main motivation here is the fact that
+things change, and what works now might not always be best. By breaking some
+tools out into their own modules, it is easier to replace and/or deprecate them
+if they are found to be insufficient.
+
+=head2 SUBTESTS
+
+=over 4
+
+=item Test::Stream::Subtest
+
+L<Test::Stream::Subtest> provides fuctions for running subtests, you can pick
+the ones that work best for you.
+
+=back
+
 =head1 EXPORTS
 
+All subs are exported by default B<except> C<context()>. You can use '-all' to
+import all subs, or you can use '-default' and specify 'context'.
+
+    use Test::Stream '-all';
+
+or
+
+    use Test::Stream '-default', 'context';
+
+You can also rename any sub on import:
+
+    use Test::Stream '-default', is_deeply => {-as => 'deep_compare'};
+
 =head2 ASSERTIONS
 
 =over 4
